Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(375)

Unified Diff: runtime/vm/deopt_instructions.h

Issue 208533004: When deoptimizing use the code stored in the deopt information instead of current unoptimized code … (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/deopt_instructions.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/deopt_instructions.h
===================================================================
--- runtime/vm/deopt_instructions.h (revision 34251)
+++ runtime/vm/deopt_instructions.h (working copy)
@@ -255,11 +255,11 @@
// set the output parameter info_number to the index of the shared suffix.
static intptr_t DecodeSuffix(intptr_t source_index, intptr_t* info_number);
// Get the function and return address which is encoded in this
// kRetAfterAddress deopt instruction.
static uword GetRetAddress(DeoptInstr* instr,
const Array& object_table,
- Function* func);
+ Code* code);
// Return number of initialized fields in the object that will be
// materialized by kMaterializeObject instruction.
« no previous file with comments | « no previous file | runtime/vm/deopt_instructions.cc » ('j') | no next file with comments »
@@ -255,11 +255,11 @@
// set the output parameter info_number to the index of the shared suffix.
static intptr_t DecodeSuffix(intptr_t source_index, intptr_t* info_number);
- // Get the function and return address which is encoded in this
+ // Get the code and return address which is encoded in this
// kRetAfterAddress deopt instruction.
static uword GetRetAddress(DeoptInstr* instr,

Powered by Google App Engine
This is Rietveld 408576698